// InterruptibleCursor.cpp: implementation of the CInterruptibleCursor class.
// Copyright (c) 2021 by David Wincelberg
//////////////////////////////////////////////////////////////////////

#include "pch.h"
#include "InterruptibleCursor.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

// Action:	Sets the cursor (or pointer) to the one with an arrow and a wait indicator.
CInterruptibleCursor::CInterruptibleCursor (bool bDelay /* = false */)
{
	m_curNormal = ::LoadCursor (nullptr, IDC_ARROW);
	m_curMixed  = ::LoadCursor (nullptr, IDC_APPSTARTING);

	if (m_curNormal == nullptr) {
		m_curMixed = nullptr;	// Changes cursor only if normal one is loaded.
	}

	if (!bDelay) {
		Restore();
	}
}	// CInterruptibleCursor


// Action:	Restores the normal cursor.
CInterruptibleCursor::~CInterruptibleCursor()
{
	Clear();
}	// ~CInterruptibleCursor


// Action:	Sets or restores the interruptible cursor.
void CInterruptibleCursor::Restore()
{
	if (m_curMixed != nullptr) {
		::SetCursor(m_curMixed);
	}
}	// Restore


// Action:	Clears the interruptible cursor.
void CInterruptibleCursor::Clear()
{
	if (m_curNormal != nullptr) {
		::SetCursor(m_curNormal);
	}
}	// Clear
